@@ -1,3 +1,5 @@
+import asyncio
+
 from piou import Cli, Option, Derived
 
 cli = Cli(description='A CLI tool')
@@ -14,9 +16,19 @@ def get_pg_url(
     return f'postgresql://{pg_user}:{pg_pwd}@{pg_host}:{pg_port}/{pg_db}'
 
 
+async def get_sleep(
+        duration: float = Option(0.01, '--duration'),
+):
+    await asyncio.sleep(duration)
+    return True
+
+
 @cli.command(help='Run foo command')
-def foo(pg_url: str = Derived(get_pg_url)):
-    print(pg_url)
+def foo(
+        pg_url: str = Derived(get_pg_url),
+        has_slept: bool = Derived(get_sleep)
+):
+    print(has_slept, pg_url)
 
 
 if __name__ == '__main__':
